Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1069)

Unified Diff: net/disk_cache/blockfile/backend_impl.cc

Issue 2894863002: Rename TaskRunner::RunsTasksOnCurrentThread() in //net (Closed)
Patch Set: for Requirements Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/disk_cache/blockfile/backend_impl.cc
diff --git a/net/disk_cache/blockfile/backend_impl.cc b/net/disk_cache/blockfile/backend_impl.cc
index 4557531fc273f3a723cfbcc7f56d289327fe0a67..2dd24cca4491f5c2cbd86f14b4d94de73a487d10 100644
--- a/net/disk_cache/blockfile/backend_impl.cc
+++ b/net/disk_cache/blockfile/backend_impl.cc
@@ -179,8 +179,8 @@ BackendImpl::~BackendImpl() {
background_queue_.DropPendingIO();
}
- if (background_queue_.BackgroundIsCurrentThread()) {
- // Unit tests may use the same thread for everything.
+ if (background_queue_.BackgroundIsCurrentSequence()) {
+ // Unit tests may use the same sequence for everything.
CleanupCache();
} else {
background_queue_.background_thread()->PostTask(

Powered by Google App Engine
This is Rietveld 408576698